@@ -34,7 +34,7 @@ from time import sleep
 import psycopg2 as pg
 
 from tdvisu.dijkstra import bidirectional_dijkstra as find_path
-from tdvisu.dijkstra import convert_to_adj
+from tdvisu.utilities import convert_to_adj
 from tdvisu.reader import TwReader
 from tdvisu.visualization import flatten
 from tdvisu.version import __date__, __version__ as version
@@ -143,7 +143,7 @@ class IDpdbVisuConstruct(metaclass=abc.ABCMeta):
 
 
 class DpdbSharpSatVisu(IDpdbVisuConstruct):
-    """Implementation of the JSON-Construction for the SharpSat problem."""
+    """Implementation of the JSON-construction for the SharpSat problem."""
 
     def __init__(self, db: pg.extensions.connection,
                  problem: int, intermed_nodes: bool):
@@ -207,12 +207,12 @@ class DpdbSharpSatVisu(IDpdbVisuConstruct):
 
     def read_num_vars(self) -> int:
         """
-        Select the number of "vertices" in the graph.
+        Select the number of vertices in the graph.
 
         Returns
         -------
         int
-            Number of "vertices" in the graph.
+            Number of vertices in the graph.
 
         """
         with self.connection.cursor() as cur:  # create a cursor
@@ -224,7 +224,7 @@ class DpdbSharpSatVisu(IDpdbVisuConstruct):
             return self.num_vars
 
     def read_clauses(self) -> list:
-        """Return the clauses used for satiyfiability.
+        """Return the clauses used for satisfiability.
         Variables are counted from 1 and negative if negated in the clause.
         For example:
 
@@ -251,8 +251,7 @@ class DpdbSharpSatVisu(IDpdbVisuConstruct):
 
     def read_labeldict(self) -> list:
         """
-        Read from '_td_bag' the edges and 'td_node_status' tables the labels
-        for the bags.
+        Read edges from '_td_bag' and the labels from 'td_node_status' for the bags.
 
         Returns
         -------
@@ -365,10 +364,18 @@ class DpdbSharpSatVisu(IDpdbVisuConstruct):
         return "sum: " + str(sum([li[-1] for li in lines]))
 
 
-class DpdbMinVcVisu(DpdbSharpSatVisu):
-    """Implementation of the JSON-Construction for the MinVC problem.
-    Borrowing methods from DpdbSharpSatVisu.
+class DpdbSatVisu(DpdbSharpSatVisu):
+    """Implementation of the JSON-construction for the SAT problem.
+    Removing the solution sum in bottom-label.
     """
+    @staticmethod
+    def footer(lines):
+        """Returns empty footer."""
+        return ""
+
+
+class DpdbMinVcVisu(DpdbSharpSatVisu):
+    """Implementation of the JSON-construction for the MinVC problem."""
 
     def __init__(self, db, problem, intermed_nodes, tw_file=None):
         super().__init__(db, problem, intermed_nodes)
@@ -406,7 +413,6 @@ class DpdbMinVcVisu(DpdbSharpSatVisu):
 
     def construct(self):
         """
-
         Construct the Json calling several helper methods.
 
         Returns
@@ -434,7 +440,7 @@ class DpdbMinVcVisu(DpdbSharpSatVisu):
 
 
 def connect() -> pg.extensions.connection:
-    """Connect to the PostgreSQL database server using the params from config"""
+    """Connect to the PostgreSQL database server using the params from config."""
 
     conn = None
     try:
@@ -456,7 +462,8 @@ def connect() -> pg.extensions.connection:
 
 
 def create_json(problem: int, tw_file=None, intermed_nodes=False) -> dict:
-    """Create the JSON for the specified Problem instance."""
+    """Create the JSON for the specified problem instance."""
+
     try:
         with connect() as connection:
             # get type of problem
@@ -468,7 +475,10 @@ def create_json(problem: int, tw_file=None, intermed_nodes=False) -> dict:
             # select the valid constructor for the problem
             constructor: IDpdbVisuConstruct
 
-            if ptype == 'SharpSat':
+            if ptype == 'Sat':
+                constructor = DpdbSatVisu(
+                    connection, problem, intermed_nodes)
+            elif ptype == 'SharpSat':
                 constructor = DpdbSharpSatVisu(
                     connection, problem, intermed_nodes)
             elif ptype == 'VertexCover':
@@ -479,7 +489,6 @@ def create_json(problem: int, tw_file=None, intermed_nodes=False) -> dict:
                         constructor.__class__.__name__, ptype)
             LOGGER.info("Constructing Json...")
             return constructor.construct()
-
     except (Exception, pg.DatabaseError) as error:
         LOGGER.error(error)
         raise error
@@ -550,19 +559,19 @@ if __name__ == "__main__":
     )
 
     PARSER.add_argument('problemnumber', type=int,
-                        help="problem-id in the postgres-database.")
+                        help="selected problem-id in the postgres-database.")
     PARSER.add_argument('--twfile',
                         type=argparse.FileType('r', encoding='UTF-8'),
-                        help="tw-File containing the edges of the graph - "
+                        help="tw-file containing the edges of the graph - "
                         "obtained from dpdb with option --gr-file GR_FILE.")
     PARSER.add_argument('--loglevel', help="set the minimal loglevel for root")
     PARSER.add_argument('--outfile', default='dbjson%d.json',
                         help="default:'dbjson%%d.json'")
     PARSER.add_argument('--pretty', action='store_true',
-                        help="Pretty-print the JSON.")
+                        help="pretty-print the JSON.")
     PARSER.add_argument('--inter-nodes', action='store_true',
-                        help="Calculate path between successive nodes "
-                        "during the evaluation order.")
+                        help="calculate and animate the shortest path between "
+                        "successive bags in the order of evaluation.")
     PARSER.add_argument('--version', action='version',
                         version='%(prog)s ' + version + ', ' + __date__)
 
